#include "game.h"

#ifndef __RAYLIB__
#define __RAYLIB__
#include "raylib.h"
#endif
#include "ball.h"
#include "paddle.h"

Ball ball = Ball();
Paddle player = Paddle(); 
CPUPaddle AI = CPUPaddle();

Game::Game(int width, int height, std::string title) 
{
    SetTargetFPS(60);               // Set our game to run at 60 frames-per-second
    InitWindow(width, height, title.c_str()); 
    
    screenWidth = width; 
    screenHeight = height;  
    
    ball.SetScreenSize(screenWidth, screenHeight);
    player.Init();
    AI.Init();
}

Game::~Game()
{
    CloseWindow();                  // Close window and OpenGL context
} 

bool Game::GameShouldClose() const
{
    return WindowShouldClose();
}

void Game::Tick()
{
    BeginDrawing();
    Update();
    Draw();
    EndDrawing();

}

void Game::Draw()
{
        ClearBackground(BLACK);

        // Center Line
        DrawLine(screenWidth  / 2, 0, screenWidth / 2, screenHeight, RAYWHITE);

        // Draw Ball
        DrawCircle(ball.x, ball.y, ball.radius, RAYWHITE);

        // Draw Player Rectangle
        player.Draw();

        AI.Draw();
}

void Game::Update()
{
    ball.Update();
    Vector2 ballPos = {ball.x, ball.y};  // 공의 위치 

    player.Update();
    Rectangle playerRect = player.getRect(); // 플레이어 위치 가져오기 
    
    if (CheckCollisionCircleRec(ballPos, ball.radius, playerRect)) {ball.Bounce(1);};  // 플레이어와 공과의 충돌 확인
    
    AI.Update(ball.x, ball.y, ball.radius);
    Rectangle AIRect = AI.getRect();   // AI 이치 가져오기 
    if (CheckCollisionCircleRec(ballPos, ball.radius, AIRect)) {ball.Bounce(0);};  // AI와 공과의 충돌 확인 

}
